summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaway.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteaway.h')
-rw-r--r--kopete/libkopete/kopeteaway.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kopete/libkopete/kopeteaway.h b/kopete/libkopete/kopeteaway.h
index 544dff75..b907f024 100644
--- a/kopete/libkopete/kopeteaway.h
+++ b/kopete/libkopete/kopeteaway.h
@@ -19,9 +19,9 @@
#ifndef KOPETEAWAY_HI
#define KOPETEAWAY_HI
-#include <qstring.h>
-#include <qobject.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqobject.h>
+#include <tqvaluelist.h>
#include "kopeteawaydialog.h"
#include "kopete_export.h"
@@ -72,13 +72,13 @@ public:
* @brief Gets the current global away message
* @return The global away message
*/
- static QString message();
+ static TQString message();
/**
* @brief Gets the current global auto away message
* @return The global auto away message
*/
- static QString autoAwayMessage();
+ static TQString autoAwayMessage();
/**
* This method sets the global away message,
@@ -86,7 +86,7 @@ public:
* @brief Sets the global away message
* @param message The message you want to set
*/
- void setGlobalAwayMessage(const QString &message);
+ void setGlobalAwayMessage(const TQString &message);
/**
* This method sets the global auto away message,
@@ -94,7 +94,7 @@ public:
* @brief Sets the global auto away message
* @param message The message you want to set
*/
- void setAutoAwayMessage(const QString &message);
+ void setAutoAwayMessage(const TQString &message);
/**
* @brief Sets global away for all protocols
@@ -111,11 +111,11 @@ public:
* @brief Function to get the titles of user defined away messages
* @return List of away message titles
*
* This function can be used to retrieve a QStringList of the away message titles,
* these titles can be passed to getMessage(QString title) to retrieve the
* corresponding message.
*/
- QStringList getMessages();
+ TQStringList getMessages();
/**
* @brief Function to get an away message
@@ -125,7 +125,7 @@ public:
* This function retrieves the away message that corresponds to the ringbuffer index
* passed in.
*/
- QString getMessage( uint messageNumber );
+ TQString getMessage( uint messageNumber );
/**
* @brief Adds an away message to the ringbuffer
@@ -134,7 +134,7 @@ public:
* This function will add an away message to the ringbuffer of user defined
* away messages.
*/
- void addMessage(const QString &message);
+ void addMessage(const TQString &message);
/**
* time in seconds the user has been idle
@@ -111,11 +111,11 @@ public:
* @return List of away message titles
*
- * This function can be used to retrieve a QStringList of the away message titles,
- * these titles can be passed to getMessage(QString title) to retrieve the
+ * This function can be used to retrieve a TQStringList of the away message titles,
+ * these titles can be passed to getMessage(TQString title) to retrieve the
* corresponding message.
*/